@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ar">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
 <context>
     <name>App.About</name>
     <message>
@@ -12,6 +10,128 @@
         <translation>مراقب النظام هو أداة لمراقبة تحميل النظام في الوقت الفعلي، وعمليات العرض والتحكم، والخدمات التي تعمل على نظامك.</translation>
     </message>
 </context>
+<context>
+    <name>BaseDetailViewWidget</name>
+    <message>
+        <source>Hide details</source>
+        <translation>إخفاء التفاصيل</translation>
+    </message>
+    <message>
+        <source>Overall utilization</source>
+        <translation>الاستخدام الكلي</translation>
+    </message>
+    <message>
+        <source>Individual utilization</source>
+        <translation>الاستخدام الفردي</translation>
+    </message>
+</context>
+<context>
+    <name>BlockDevItemWidget</name>
+    <message>
+        <source>Read</source>
+        <translation>قراءة</translation>
+    </message>
+    <message>
+        <source>Write</source>
+        <translation>كتابة</translation>
+    </message>
+</context>
+<context>
+    <name>CPUDetailGrapTableItem</name>
+    <message>
+        <source>60 seconds</source>
+        <translation>60 ثانية </translation>
+    </message>
+</context>
+<context>
+    <name>CPUInfoModel</name>
+    <message>
+        <source>%1 days %2 hours %3 minutes</source>
+        <translation>%1 أيام %2 ساعة %3 دقيقة</translation>
+    </message>
+</context>
+<context>
+    <name>CPUSummaryTableModel</name>
+    <message>
+        <source>Utilization</source>
+        <translation>الاستخدام</translation>
+    </message>
+    <message>
+        <source>Current frequency</source>
+        <translation>التردد الحالي</translation>
+    </message>
+    <message>
+        <source>Frequency</source>
+        <translation>التردد</translation>
+    </message>
+    <message>
+        <source>Sockets</source>
+        <translation>بوكات</translation>
+    </message>
+    <message>
+        <source>Logical processors</source>
+        <translation>معالجات منطقية</translation>
+    </message>
+    <message>
+        <source>Virtualization</source>
+        <translation>الأفتراضية</translation>
+    </message>
+    <message>
+        <source>L1i cache</source>
+        <translation>كاش L1i</translation>
+    </message>
+    <message>
+        <source>L1d cache</source>
+        <translation>كاش L1d</translation>
+    </message>
+    <message>
+        <source>L2 cache</source>
+        <translation>كاش L2</translation>
+    </message>
+    <message>
+        <source>L3 cache</source>
+        <translation>كاش L3</translation>
+    </message>
+    <message>
+        <source>Load average</source>
+        <translation>معدل الحمل</translation>
+    </message>
+    <message>
+        <source>File descriptors</source>
+        <translation>التص jurوص الملف</translation>
+    </message>
+    <message>
+        <source>Processes</source>
+        <translation>العمليات</translation>
+    </message>
+    <message>
+        <source>Threads</source>
+        <translation>عنصر THREADS</translation>
+    </message>
+    <message>
+        <source>Host name</source>
+        <translation>اسم المستضيف</translation>
+    </message>
+    <message>
+        <source>OS type</source>
+        <translation>نوع نظام التشغيل</translation>
+    </message>
+    <message>
+        <source>Version</source>
+        <translation>النسخة</translation>
+    </message>
+    <message>
+        <source>Up time</source>
+        <translation>وقت التشغيل</translation>
+    </message>
+</context>
+<context>
+    <name>ChartViewWidget</name>
+    <message>
+        <source>60 seconds</source>
+        <translation>60 ثانية </translation>
+    </message>
+</context>
 <context>
     <name>Common.Search</name>
     <message>
@@ -20,18 +140,17 @@
     </message>
 </context>
 <context>
-    <name>Core</name>
+    <name>CompactCpuMonitor</name>
     <message>
-        <source>60 seconds</source>
-        <translation type="unfinished"></translation>
+        <source>Details</source>
+        <translation>تفاصيل</translation>
     </message>
+</context>
+<context>
+    <name>CpuMonitor</name>
     <message>
-        <source>5 minutes</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>15 minutes</source>
-        <translation type="unfinished"></translation>
+        <source>Details</source>
+        <translation>تفاصيل</translation>
     </message>
 </context>
 <context>
@@ -210,36 +329,143 @@
     </message>
 </context>
 <context>
-    <name>DetailViewStackedWidget</name>
+    <name>DBusAlarmNotify</name>
     <message>
-        <source>View performance parameters</source>
-        <translation type="unfinished"></translation>
+        <source>Warning</source>
+        <translation>تحذير</translation>
     </message>
     <message>
-        <source>Hiding performance parameters</source>
-        <translation type="unfinished"></translation>
+        <source>Your CPU usage is higher than %1%!</source>
+        <translation>استهلاك معالجك أعلى من %1%</translation>
     </message>
     <message>
-        <source>CPU</source>
-        <translation type="unfinished">المعالج</translation>
+        <source>Your memory usage is higher than %1%!</source>
+        <translation>استهلاك пاومةك أعلى من %1%</translation>
     </message>
     <message>
-        <source>Memory</source>
-        <translation type="unfinished">الذاكرة</translation>
+        <source>View</source>
+        <translation>عرض</translation>
+    </message>
+</context>
+<context>
+    <name>DeailTableModel</name>
+    <message>
+        <source>Used</source>
+        <translation>المستخدم</translation>
     </message>
     <message>
-        <source>Netif</source>
-        <translation type="unfinished"></translation>
+        <source>Available</source>
+        <translation>المتاح</translation>
     </message>
     <message>
-        <source>BlockDev</source>
-        <translation type="unfinished"></translation>
+        <source>Shared</source>
+        <translation>مشترك</translation>
+    </message>
+    <message>
+        <source>Cached</source>
+        <translation>محكم الصache</translation>
+    </message>
+    <message>
+        <source>Buffers</source>
+        <translation>البوثرز</translation>
+    </message>
+    <message>
+        <source>Cached swap</source>
+        <translation>تبديل محكم الشايف</translation>
+    </message>
+    <message>
+        <source>Active</source>
+        <translation>تفعيل</translation>
+    </message>
+    <message>
+        <source>Inactive</source>
+        <translation>غير نشط</translation>
+    </message>
+    <message>
+        <source>Dirty</source>
+        <translation>مشوه</translation>
+    </message>
+    <message>
+        <source>Mapped</source>
+        <translation>مخرزا</translation>
+    </message>
+    <message>
+        <source>Total swap</source>
+        <translation>إجمالي التبديل</translation>
+    </message>
+    <message>
+        <source>Free swap</source>
+        <translation>空間交換</translation>
+    </message>
+    <message>
+        <source>Slab</source>
+        <translation>استل</translation>
+    </message>
+</context>
+<context>
+    <name>DeailTableModelBlock</name>
+    <message>
+        <source>Model</source>
+        <translation>النموذج</translation>
+    </message>
+    <message>
+        <source>Read speed</source>
+        <translation>سرعة القراءة</translation>
+    </message>
+    <message>
+        <source>Write speed</source>
+        <translation>سرعة الكتابة</translation>
+    </message>
+    <message>
+        <source>Capacity</source>
+        <translation>السعة</translation>
+    </message>
+    <message>
+        <source>Sectors read</source>
+        <translation>اقرأ مجالات</translation>
+    </message>
+    <message>
+        <source>Reads/s</source>
+        <translation>قراءات في الثانية</translation>
+    </message>
+    <message>
+        <source>Sectors read/s</source>
+        <translation>مجالات قرأ في الثانية</translation>
+    </message>
+    <message>
+        <source>Reads merged/s</source>
+        <translation>/navbar-objects/merged- mũiٍ‏تم في الثانية</translation>
+    </message>
+    <message>
+        <source>Sectors written</source>
+        <translation>تم написة مجالات</translation>
+    </message>
+    <message>
+        <source>Writes completed </source>
+        <translation>الihnامات مكتملة</translation>
+    </message>
+    <message>
+        <source>Writes merged</source>
+        <translation>ال Writes مدمجة</translation>
+    </message>
+    <message>
+        <source>Writes/s</source>
+        <translation>كتابة في الثانية</translation>
+    </message>
+    <message>
+        <source>Sectors written/s</source>
+        <translation>مجالات مكتوبة في الثانية</translation>
+    </message>
+    <message>
+        <source>Writes merged/s</source>
+        <translation>ال نُسخة مدمجة في الثانية</translation>
     </message>
 </context>
 <context>
     <name>Error.Dialog</name>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>موافق</translation>
     </message>
 </context>
@@ -262,10 +488,6 @@ Are you sure you want to continue?</source>
         <translation>قد يؤدي إنهاء هذه العملية إلى فقدان البيانات
 هل أنت متأكد من المتابعة؟</translation>
     </message>
-    <message>
-        <source>Cancel</source>
-        <translation>إلغاء</translation>
-    </message>
     <message>
         <source>End process</source>
         <translation>إنهاء العملية</translation>
@@ -276,20 +498,151 @@ Are you sure you want to continue?</source>
         <translation>قد يؤدي فرض إنهاء هذه العملية إلى فقدان البيانات
 هل أنت متأكد من المتابعة؟</translation>
     </message>
-    <message>
-        <source>End</source>
-        <translation>انهاء</translation>
-    </message>
     <message>
         <source>Force ending this application may cause data loss.
 Are you sure you want to continue?</source>
         <translation>قد يؤدي فرض إنهاء هذا التطبيق إلى فقدان البيانات
 هل أنت متأكد من المتابعة؟</translation>
     </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>إلغاء</translation>
+    </message>
     <message>
         <source>Force End</source>
+        <comment>button</comment>
         <translation>انهاء اجباري</translation>
     </message>
+    <message>
+        <source>End</source>
+        <comment>button</comment>
+        <translation>انهاء</translation>
+    </message>
+</context>
+<context>
+    <name>MainWindow</name>
+    <message>
+        <source>Settings</source>
+        <translation>الإعدادات</translation>
+    </message>
+</context>
+<context>
+    <name>MemStatViewWidget</name>
+    <message>
+        <source>Size</source>
+        <translation>الحجم</translation>
+    </message>
+</context>
+<context>
+    <name>NetInfoDetailItemDelegate</name>
+    <message>
+        <source>IP address:</source>
+        <translation>عنوان بروتوكول الإنترنت (IP)</translation>
+    </message>
+    <message>
+        <source>Netmask:</source>
+        <translation>خمار الشبكة:</translation>
+    </message>
+    <message>
+        <source>Broadcast:</source>
+        <translation>تنقل:</translation>
+    </message>
+    <message>
+        <source>Prefixlen:</source>
+        <translation>الحctime:</translation>
+    </message>
+    <message>
+        <source>Scope:</source>
+        <translation>معرض:</translation>
+    </message>
+</context>
+<context>
+    <name>NetInfoModel</name>
+    <message>
+        <source>Connection type</source>
+        <translation>نوع الإتصال</translation>
+    </message>
+    <message>
+        <source>ESSID</source>
+        <translation>اسم مجموعة الشبكة</translation>
+    </message>
+    <message>
+        <source>Link quality</source>
+        <translation>جودة الإتصال</translation>
+    </message>
+    <message>
+        <source>Signal strength</source>
+        <translation>قوة الإشارة</translation>
+    </message>
+    <message>
+        <source>Noise level</source>
+        <translation>مستوى الضوضاء</translation>
+    </message>
+    <message>
+        <source>MAC</source>
+        <translation>العنوان المتميّز لظلال الكابلات</translation>
+    </message>
+    <message>
+        <source>Bandwidth</source>
+        <translation>عرض النطاق الترددي</translation>
+    </message>
+    <message>
+        <source>RX packets</source>
+        <translation>بركات المدخلات</translation>
+    </message>
+    <message>
+        <source>RX bytes</source>
+        <translation>بايتس المدخل</translation>
+    </message>
+    <message>
+        <source>RX errors</source>
+        <translation>أخطاء المدخل</translation>
+    </message>
+    <message>
+        <source>RX dropped</source>
+        <translation>تخلى عن المدخل</translation>
+    </message>
+    <message>
+        <source>RX overruns</source>
+        <translation>التجاوزات على المدخل</translation>
+    </message>
+    <message>
+        <source>RX frame</source>
+        <translation>مرamesة وردت</translation>
+    </message>
+    <message>
+        <source>TX packets</source>
+        <translation>تذاكر إرسال</translation>
+    </message>
+    <message>
+        <source>TX bytes</source>
+        <translation>بتات إرسال</translation>
+    </message>
+    <message>
+        <source>TX errors</source>
+        <translation>خطايات إرسال</translation>
+    </message>
+    <message>
+        <source>TX overruns</source>
+        <translation> crossings إرسال</translation>
+    </message>
+    <message>
+        <source>TX carrier</source>
+        <translation>محرِّر إرسال</translation>
+    </message>
+    <message>
+        <source>IPv4</source>
+        <translation>IPv4</translation>
+    </message>
+    <message>
+        <source>IPv6</source>
+        <translation>IPv6</translation>
+    </message>
+    <message>
+        <source>TX dropped</source>
+        <translation>تذاكر محذوفة إرسال</translation>
+    </message>
 </context>
 <context>
     <name>Process.Attributes.Dialog</name>
@@ -319,6 +672,10 @@ Are you sure you want to continue?</source>
         <source>Memory</source>
         <translation>الذاكرة</translation>
     </message>
+    <message>
+        <source>Receive</source>
+        <translation>المستلم</translation>
+    </message>
 </context>
 <context>
     <name>Process.Graph.View</name>
@@ -354,10 +711,6 @@ Are you sure you want to continue?</source>
         <source>Upload</source>
         <translation>الرفع</translation>
     </message>
-    <message>
-        <source>Disk</source>
-        <translation>القرص</translation>
-    </message>
     <message>
         <source>Network</source>
         <translation>الشبكة</translation>
@@ -370,6 +723,21 @@ Are you sure you want to continue?</source>
         <source>Total Sent</source>
         <translation>الإرسال الإجمالي</translation>
     </message>
+    <message>
+        <source>Send</source>
+        <translation>المرسل</translation>
+    </message>
+    <message>
+        <source>Disks</source>
+        <translation>الأقراص</translation>
+    </message>
+</context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>تحميل</translation>
+    </message>
 </context>
 <context>
     <name>Process.Priority</name>
@@ -507,18 +875,20 @@ Are you sure you want to continue?</source>
 </context>
 <context>
     <name>Process.Table.Custom.Priority.Dialog</name>
+    <message>
+        <source>Custom Priority</source>
+        <translation>أولوية مخصصة</translation>
+    </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>إلغاء</translation>
     </message>
     <message>
         <source>Change</source>
+        <comment>button</comment>
         <translation>تغيير</translation>
     </message>
-    <message>
-        <source>Custom Priority</source>
-        <translation>أولوية مخصصة</translation>
-    </message>
 </context>
 <context>
     <name>Process.Table.Header</name>
@@ -566,6 +936,49 @@ Are you sure you want to continue?</source>
         <source>Priority</source>
         <translation>أولوية</translation>
     </message>
+    <message>
+        <source>Shared memory</source>
+        <translation>الذاكرة المشتركة</translation>
+    </message>
+    <message>
+        <source>Virtual memory</source>
+        <translation>الذاكرة الإفتراضية </translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Not support</source>
+        <translation>غير مدعوم</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>الإعدادات</translation>
+    </message>
+    <message>
+        <source>System Protection</source>
+        <translation>حماية النظام</translation>
+    </message>
+    <message>
+        <source>Show warnings when the usage exceeds the thresholds</source>
+        <translation>إظهار التنبيهات عندما تتجاوز الاستخدام المعايير</translation>
+    </message>
+    <message>
+        <source>CPU warning threshold (%)</source>
+        <translation>حد_warنات CPU (%) </translation>
+    </message>
+    <message>
+        <source>Memory warning threshold (%)</source>
+        <translation>حد_warنات الذاكرة (%) </translation>
+    </message>
+    <message>
+        <source>Warning interval (min)</source>
+        <translation>ص_majorنح Warning (دقائق</translation>
+    </message>
+    <message>
+        <source>Notifications</source>
+        <translation>التنبيهات</translation>
+    </message>
 </context>
 <context>
     <name>Service.Action.Set.Startup.Mode</name>
@@ -580,6 +993,20 @@ Are you sure you want to continue?</source>
 </context>
 <context>
     <name>Service.Instance.Name.Dialog</name>
+    <message>
+        <source>Service instance name</source>
+        <translation>اسم مثيل الخدمة</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <comment>button</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>OK</source>
         <translation>موافق</translation>
@@ -588,10 +1015,6 @@ Are you sure you want to continue?</source>
         <source>Cancel</source>
         <translation>إلغاء</translation>
     </message>
-    <message>
-        <source>Service instance name</source>
-        <translation>اسم مثيل الخدمة</translation>
-    </message>
 </context>
 <context>
     <name>Service.Table.Context.Menu</name>
@@ -636,7 +1059,7 @@ Are you sure you want to continue?</source>
     </message>
     <message>
         <source>Active</source>
-        <translation>تفعيل</translation>
+        <translation type="vanished">تفعيل</translation>
     </message>
     <message>
         <source>Sub</source>
@@ -644,7 +1067,7 @@ Are you sure you want to continue?</source>
     </message>
     <message>
         <source>State</source>
-        <translation>حالة</translation>
+        <translation type="vanished">حالة</translation>
     </message>
     <message>
         <source>Description</source>
@@ -658,6 +1081,29 @@ Are you sure you want to continue?</source>
         <source>Startup Type</source>
         <translation>نوع بدء التشغيل</translation>
     </message>
+    <message>
+        <source>Start State</source>
+        <translation>حالة البدء</translation>
+    </message>
+    <message>
+        <source>Start Tactic</source>
+        <translation>technique البدء</translation>
+    </message>
+</context>
+<context>
+    <name>SystemProtectionSetting</name>
+    <message>
+        <source>Settings</source>
+        <translation>الإعدادات</translation>
+    </message>
+    <message>
+        <source>(Modifiable)</source>
+        <translation>(قابل للتغيير</translation>
+    </message>
+    <message>
+        <source>Range: %1-%2</source>
+        <translation>م范畴: %1-%2</translation>
+    </message>
 </context>
 <context>
     <name>Title.Bar.Context.Menu</name>
@@ -695,19 +1141,27 @@ Are you sure you want to continue?</source>
         <source>Services</source>
         <translation>الخدمات</translation>
     </message>
-</context>
-<context>
-    <name>up %1 days(s)</name>
-    <message numerus="yes">
-        <source>SysInfo.Uptime</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-        </translation>
+    <message>
+        <source>Users</source>
+        <translation>المستخدمون </translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>User.Account.Type</name>
+    <message>
+        <source>Administrator</source>
+        <translation>المسؤول</translation>
+    </message>
+    <message>
+        <source>Standard User</source>
+        <translation>المستخدم الإفتراضي</translation>
+    </message>
+</context>
+<context>
+    <name>User.Account.Operation</name>
+    <message>
+        <source>Edit account information</source>
+        <translation>تعديل معلومات الحساب</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
