@@ -64,10 +64,6 @@
         <source>Frequency</source>
         <translation>Taajuus</translation>
     </message>
-    <message>
-        <source>Vendor</source>
-        <translation>Valmistaja</translation>
-    </message>
     <message>
         <source>Sockets</source>
         <translation>Korttipaikat</translation>
@@ -325,13 +321,32 @@
     </message>
     <message>
         <source>failed</source>
-        <translation>Epäonnistui</translation>
+        <translation>epäonnistui</translation>
     </message>
     <message>
         <source>auto-restart</source>
         <translation>autom-käynnistys</translation>
     </message>
 </context>
+<context>
+    <name>DBusAlarmNotify</name>
+    <message>
+        <source>Warning</source>
+        <translation>Varoitus</translation>
+    </message>
+    <message>
+        <source>Your CPU usage is higher than %1%!</source>
+        <translation>Suorittimen käyttö on korkeampi kuin %1%!</translation>
+    </message>
+    <message>
+        <source>Your memory usage is higher than %1%!</source>
+        <translation>Muistin käyttö on korkeampi kuin %1%!</translation>
+    </message>
+    <message>
+        <source>View</source>
+        <translation>Katso</translation>
+    </message>
+</context>
 <context>
     <name>DeailTableModel</name>
     <message>
@@ -717,6 +732,13 @@ Haluatko varmasti jatkaa?</translation>
         <translation>Levyt</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Ladataan</translation>
+    </message>
+</context>
 <context>
     <name>Process.Priority</name>
     <message>
@@ -771,13 +793,6 @@ Haluatko varmasti jatkaa?</translation>
         <translation>Kaikki prosessit</translation>
     </message>
 </context>
-<context>
-    <name>Process.Loading</name>
-    <message>
-        <source>Loading</source>
-        <translation>Ladataan</translation>
-    </message>
-</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -847,7 +862,7 @@ Haluatko varmasti jatkaa?</translation>
     </message>
     <message>
         <source>Kill process</source>
-        <translation>Tapa prosessi</translation>
+        <translation>Lopeta prosessi</translation>
     </message>
     <message>
         <source>Change priority</source>
@@ -883,11 +898,11 @@ Haluatko varmasti jatkaa?</translation>
     </message>
     <message>
         <source>CPU</source>
-        <translation>Prosessori</translation>
+        <translation>Kuorma</translation>
     </message>
     <message>
         <source>Memory</source>
-        <translation>Muisti</translation>
+        <translation>Muisti </translation>
     </message>
     <message>
         <source>Disk write</source>
@@ -948,10 +963,6 @@ Haluatko varmasti jatkaa?</translation>
         <source>Show warnings when the usage exceeds the thresholds</source>
         <translation>Näytä varoitukset, kun käyttö ylittää kynnysarvot</translation>
     </message>
-    <message>
-        <source>Notifications</source>
-        <translation>Ilmoitukset</translation>
-    </message>
     <message>
         <source>CPU warning threshold (%)</source>
         <translation>CPU varoituskynnys (%)</translation>
@@ -964,6 +975,10 @@ Haluatko varmasti jatkaa?</translation>
         <source>Warning interval (min)</source>
         <translation>Varoitusväli (min)</translation>
     </message>
+    <message>
+        <source>Notifications</source>
+        <translation>Ilmoitukset</translation>
+    </message>
 </context>
 <context>
     <name>Service.Action.Set.Startup.Mode</name>
@@ -985,11 +1000,19 @@ Haluatko varmasti jatkaa?</translation>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>OK</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation>Peru</translation>
     </message>
 </context>
@@ -1036,7 +1059,7 @@ Haluatko varmasti jatkaa?</translation>
     </message>
     <message>
         <source>Active</source>
-        <translation>Aktiivinen</translation>
+        <translation type="vanished">Aktiivinen</translation>
     </message>
     <message>
         <source>Sub</source>
@@ -1044,7 +1067,7 @@ Haluatko varmasti jatkaa?</translation>
     </message>
     <message>
         <source>State</source>
-        <translation>Tila</translation>
+        <translation type="vanished">Tila</translation>
     </message>
     <message>
         <source>Description</source>
@@ -1058,6 +1081,14 @@ Haluatko varmasti jatkaa?</translation>
         <source>Startup Type</source>
         <translation>Käynnistyksen tyyppi</translation>
     </message>
+    <message>
+        <source>Start State</source>
+        <translation>Aloitustila</translation>
+    </message>
+    <message>
+        <source>Start Tactic</source>
+        <translation>Aloitustaktiikka</translation>
+    </message>
 </context>
 <context>
     <name>SystemProtectionSetting</name>
@@ -1110,7 +1141,7 @@ Haluatko varmasti jatkaa?</translation>
         <source>Services</source>
         <translation>Palvelut</translation>
     </message>
-   <message>
+    <message>
         <source>Users</source>
         <translation>Käyttäjät</translation>
     </message>
@@ -1133,4 +1164,4 @@ Haluatko varmasti jatkaa?</translation>
         <translation>Muokkaa tilitietoja</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
