@@ -64,10 +64,6 @@
         <source>Frequency</source>
         <translation>Snelheid</translation>
     </message>
-    <message>
-        <source>Vendor</source>
-        <translation>Maker</translation>
-    </message>
     <message>
         <source>Sockets</source>
         <translation>Sockets</translation>
@@ -332,6 +328,25 @@
         <translation>automatisch herstarten</translation>
     </message>
 </context>
+<context>
+    <name>DBusAlarmNotify</name>
+    <message>
+        <source>Warning</source>
+        <translation>Waarschuwing</translation>
+    </message>
+    <message>
+        <source>Your CPU usage is higher than %1%!</source>
+        <translation>Het cpu-gebruik is meer dan %1%!</translation>
+    </message>
+    <message>
+        <source>Your memory usage is higher than %1%!</source>
+        <translation>Het geheugengebruik is meer dan %1%!</translation>
+    </message>
+    <message>
+        <source>View</source>
+        <translation>Weergave</translation>
+    </message>
+</context>
 <context>
     <name>DeailTableModel</name>
     <message>
@@ -505,6 +520,13 @@ Weet je zeker dat je door wilt gaan?</translation>
         <translation>Beëindigen</translation>
     </message>
 </context>
+<context>
+    <name>MainWindow</name>
+    <message>
+        <source>Settings</source>
+        <translation>Instellingen</translation>
+    </message>
+</context>
 <context>
     <name>MemStatViewWidget</name>
     <message>
@@ -710,6 +732,13 @@ Weet je zeker dat je door wilt gaan?</translation>
         <translation>Schijven</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Bezig met laden…</translation>
+    </message>
+</context>
 <context>
     <name>Process.Priority</name>
     <message>
@@ -764,13 +793,6 @@ Weet je zeker dat je door wilt gaan?</translation>
         <translation>Alle processen</translation>
     </message>
 </context>
-<context>
-    <name>Process.Loading</name>
-    <message>
-        <source>Loading</source>
-        <translation>Bezig met laden…</translation>
-    </message>
-</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -941,10 +963,6 @@ Weet je zeker dat je door wilt gaan?</translation>
         <source>Show warnings when the usage exceeds the thresholds</source>
         <translation>Waarschuwingen tonen als het gebruik de drempelwaarden overstijgt</translation>
     </message>
-    <message>
-        <source>Notifications</source>
-        <translation>Meldingen</translation>
-    </message>
     <message>
         <source>CPU warning threshold (%)</source>
         <translation>Waarschuwingsdrempelwaarde cpu-gebruik (in %)</translation>
@@ -957,6 +975,10 @@ Weet je zeker dat je door wilt gaan?</translation>
         <source>Warning interval (min)</source>
         <translation>Waarschuwingtussenpoos (in min.)</translation>
     </message>
+    <message>
+        <source>Notifications</source>
+        <translation>Meldingen</translation>
+    </message>
 </context>
 <context>
     <name>Service.Action.Set.Startup.Mode</name>
@@ -978,11 +1000,19 @@ Weet je zeker dat je door wilt gaan?</translation>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>Oké</translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>Oké</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation>Annuleren</translation>
     </message>
 </context>
@@ -1029,7 +1059,7 @@ Weet je zeker dat je door wilt gaan?</translation>
     </message>
     <message>
         <source>Active</source>
-        <translation>Actief</translation>
+        <translation type="vanished">Actief</translation>
     </message>
     <message>
         <source>Sub</source>
@@ -1037,7 +1067,7 @@ Weet je zeker dat je door wilt gaan?</translation>
     </message>
     <message>
         <source>State</source>
-        <translation>Status</translation>
+        <translation type="vanished">Status</translation>
     </message>
     <message>
         <source>Description</source>
@@ -1051,6 +1081,14 @@ Weet je zeker dat je door wilt gaan?</translation>
         <source>Startup Type</source>
         <translation>Soort opstart</translation>
     </message>
+    <message>
+        <source>Start State</source>
+        <translation>Beginstatus</translation>
+    </message>
+    <message>
+        <source>Start Tactic</source>
+        <translation>Starttechniek</translation>
+    </message>
 </context>
 <context>
     <name>SystemProtectionSetting</name>
@@ -1103,7 +1141,7 @@ Weet je zeker dat je door wilt gaan?</translation>
         <source>Services</source>
         <translation>Diensten</translation>
     </message>
-   <message>
+    <message>
         <source>Users</source>
         <translation>Gebruikers</translation>
     </message>
@@ -1126,4 +1164,4 @@ Weet je zeker dat je door wilt gaan?</translation>
         <translation>Accountinformatie bewerken</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
