@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
 <context>
     <name>App.About</name>
     <message>
@@ -64,10 +64,6 @@
         <source>Frequency</source>
         <translation>Frekuencë</translation>
     </message>
-    <message>
-        <source>Vendor</source>
-        <translation>Tregtues</translation>
-    </message>
     <message>
         <source>Sockets</source>
         <translation>Socket-e</translation>
@@ -204,7 +200,7 @@
     </message>
     <message>
         <source>merged</source>
-        <translation type="unfinished"/>
+        <translation>përdorur</translation>
     </message>
     <message>
         <source>masked</source>
@@ -254,7 +250,7 @@
     </message>
     <message>
         <source>enabled-runtime</source>
-        <translation type="unfinished"/>
+        <translation>aktualizuar-dyndimë</translation>
     </message>
     <message>
         <source>masked</source>
@@ -273,7 +269,7 @@
     </message>
     <message>
         <source>start-pre</source>
-        <translation type="unfinished"/>
+        <translation>përpara-lëshjes</translation>
     </message>
     <message>
         <source>start</source>
@@ -281,7 +277,7 @@
     </message>
     <message>
         <source>start-post</source>
-        <translation type="unfinished"/>
+        <translation>përfundimtare-lëshjes</translation>
     </message>
     <message>
         <source>running</source>
@@ -289,7 +285,7 @@
     </message>
     <message>
         <source>exited</source>
-        <translation type="unfinished"/>
+        <translation>i iku</translation>
     </message>
     <message>
         <source>reload</source>
@@ -301,27 +297,27 @@
     </message>
     <message>
         <source>stop-watchdog</source>
-        <translation type="unfinished"/>
+        <translation>stop-watchdog</translation>
     </message>
     <message>
         <source>stop-sigterm</source>
-        <translation type="unfinished"/>
+        <translation>stop-sigterm</translation>
     </message>
     <message>
         <source>stop-sigkill</source>
-        <translation type="unfinished"/>
+        <translation>stop-sigkill</translation>
     </message>
     <message>
         <source>stop-post</source>
-        <translation type="unfinished"/>
+        <translation>përfundimtare-stop</translation>
     </message>
     <message>
         <source>final-sigterm</source>
-        <translation type="unfinished"/>
+        <translation>final-sigterm</translation>
     </message>
     <message>
         <source>final-sigkill</source>
-        <translation type="unfinished"/>
+        <translation>final-sigkill</translation>
     </message>
     <message>
         <source>failed</source>
@@ -332,11 +328,30 @@
         <translation>vetërinisu</translation>
     </message>
 </context>
+<context>
+    <name>DBusAlarmNotify</name>
+    <message>
+        <source>Warning</source>
+        <translation>Kujdes</translation>
+    </message>
+    <message>
+        <source>Your CPU usage is higher than %1%!</source>
+        <translation>Përdorimi juaj i CPU-së është më lart se %1%!</translation>
+    </message>
+    <message>
+        <source>Your memory usage is higher than %1%!</source>
+        <translation>Përdorimi juaj i kujtesës është më lart se %1%!</translation>
+    </message>
+    <message>
+        <source>View</source>
+        <translation>Shiheni</translation>
+    </message>
+</context>
 <context>
     <name>DeailTableModel</name>
     <message>
         <source>Used</source>
-        <translation>Të përdorur</translation>
+        <translation>Të përdorura</translation>
     </message>
     <message>
         <source>Available</source>
@@ -344,19 +359,19 @@
     </message>
     <message>
         <source>Shared</source>
-        <translation type="unfinished"/>
+        <translation>Jukshtuar</translation>
     </message>
     <message>
         <source>Cached</source>
-        <translation type="unfinished"/>
+        <translation>Shpenzuar</translation>
     </message>
     <message>
         <source>Buffers</source>
-        <translation type="unfinished"/>
+        <translation>Buffëra</translation>
     </message>
     <message>
         <source>Cached swap</source>
-        <translation type="unfinished"/>
+        <translation>Shpenzim shpenzuar</translation>
     </message>
     <message>
         <source>Active</source>
@@ -368,11 +383,11 @@
     </message>
     <message>
         <source>Dirty</source>
-        <translation type="unfinished"/>
+        <translation>Zëra</translation>
     </message>
     <message>
         <source>Mapped</source>
-        <translation type="unfinished"/>
+        <translation>Mapuar</translation>
     </message>
     <message>
         <source>Total swap</source>
@@ -384,7 +399,7 @@
     </message>
     <message>
         <source>Slab</source>
-        <translation type="unfinished"/>
+        <translation>Slab</translation>
     </message>
 </context>
 <context>
@@ -419,7 +434,7 @@
     </message>
     <message>
         <source>Reads merged/s</source>
-        <translation type="unfinished"/>
+        <translation>Lidhjejë e kuptuar/s</translation>
     </message>
     <message>
         <source>Sectors written</source>
@@ -427,11 +442,11 @@
     </message>
     <message>
         <source>Writes completed </source>
-        <translation type="unfinished"/>
+        <translation>Shkruar i përfunduar</translation>
     </message>
     <message>
         <source>Writes merged</source>
-        <translation type="unfinished"/>
+        <translation>Shkrimet lidhura</translation>
     </message>
     <message>
         <source>Writes/s</source>
@@ -443,7 +458,7 @@
     </message>
     <message>
         <source>Writes merged/s</source>
-        <translation type="unfinished"/>
+        <translation>Shkrimet lidhura/s</translation>
     </message>
 </context>
 <context>
@@ -531,15 +546,15 @@ Jeni i sigurt se doni të vazhdohet?</translation>
     </message>
     <message>
         <source>Broadcast:</source>
-        <translation type="unfinished"/>
+        <translation>Transmisioni i publikë:</translation>
     </message>
     <message>
         <source>Prefixlen:</source>
-        <translation type="unfinished"/>
+        <translation>Prefixlen:</translation>
     </message>
     <message>
         <source>Scope:</source>
-        <translation type="unfinished"/>
+        <translation>Krahësia:</translation>
     </message>
 </context>
 <context>
@@ -570,7 +585,7 @@ Jeni i sigurt se doni të vazhdohet?</translation>
     </message>
     <message>
         <source>Bandwidth</source>
-        <translation type="unfinished"/>
+        <translation>Kohësia</translation>
     </message>
     <message>
         <source>RX packets</source>
@@ -590,11 +605,11 @@ Jeni i sigurt se doni të vazhdohet?</translation>
     </message>
     <message>
         <source>RX overruns</source>
-        <translation type="unfinished"/>
+        <translation>RX overruns</translation>
     </message>
     <message>
         <source>RX frame</source>
-        <translation type="unfinished"/>
+        <translation>RAM frame</translation>
     </message>
     <message>
         <source>TX packets</source>
@@ -610,7 +625,7 @@ Jeni i sigurt se doni të vazhdohet?</translation>
     </message>
     <message>
         <source>TX overruns</source>
-        <translation type="unfinished"/>
+        <translation>TX overruns</translation>
     </message>
     <message>
         <source>TX carrier</source>
@@ -626,7 +641,7 @@ Jeni i sigurt se doni të vazhdohet?</translation>
     </message>
     <message>
         <source>TX dropped</source>
-        <translation type="unfinished"/>
+        <translation>TX dropped</translation>
     </message>
 </context>
 <context>
@@ -717,6 +732,13 @@ Jeni i sigurt se doni të vazhdohet?</translation>
         <translation>Disqe</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Po ngarkohet</translation>
+    </message>
+</context>
 <context>
     <name>Process.Priority</name>
     <message>
@@ -771,13 +793,6 @@ Jeni i sigurt se doni të vazhdohet?</translation>
         <translation>Krejt proceset</translation>
     </message>
 </context>
-<context>
-    <name>Process.Loading</name>
-    <message>
-        <source>Loading</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -915,7 +930,7 @@ Jeni i sigurt se doni të vazhdohet?</translation>
     </message>
     <message>
         <source>Nice</source>
-        <translation type="unfinished"/>
+        <translation>Nice</translation>
     </message>
     <message>
         <source>Priority</source>
@@ -948,10 +963,6 @@ Jeni i sigurt se doni të vazhdohet?</translation>
         <source>Show warnings when the usage exceeds the thresholds</source>
         <translation>Shfaq sinjalizime, kur përdorimi tejkalon pragjet</translation>
     </message>
-    <message>
-        <source>Notifications</source>
-        <translation>Njoftime</translation>
-    </message>
     <message>
         <source>CPU warning threshold (%)</source>
         <translation>Prag sinjalizimi për CPU-në (%)</translation>
@@ -964,6 +975,10 @@ Jeni i sigurt se doni të vazhdohet?</translation>
         <source>Warning interval (min)</source>
         <translation>Interval sinjalizimi (min)</translation>
     </message>
+    <message>
+        <source>Notifications</source>
+        <translation>Njoftime</translation>
+    </message>
 </context>
 <context>
     <name>Service.Action.Set.Startup.Mode</name>
@@ -982,6 +997,16 @@ Jeni i sigurt se doni të vazhdohet?</translation>
         <source>Service instance name</source>
         <translation>Emër instance shërbimi</translation>
     </message>
+    <message>
+        <source>OK</source>
+        <comment>button</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>OK</source>
         <translation>OK</translation>
@@ -1034,7 +1059,7 @@ Jeni i sigurt se doni të vazhdohet?</translation>
     </message>
     <message>
         <source>Active</source>
-        <translation>Aktiv</translation>
+        <translation type="vanished">Aktiv</translation>
     </message>
     <message>
         <source>Sub</source>
@@ -1042,7 +1067,7 @@ Jeni i sigurt se doni të vazhdohet?</translation>
     </message>
     <message>
         <source>State</source>
-        <translation>Gjendje</translation>
+        <translation type="vanished">Gjendje</translation>
     </message>
     <message>
         <source>Description</source>
@@ -1056,6 +1081,14 @@ Jeni i sigurt se doni të vazhdohet?</translation>
         <source>Startup Type</source>
         <translation>Lloj Nisjeje</translation>
     </message>
+    <message>
+        <source>Start State</source>
+        <translation>Përlancëzimi i pozicionit</translation>
+    </message>
+    <message>
+        <source>Start Tactic</source>
+        <translation>Metoda e përlancëzimit</translation>
+    </message>
 </context>
 <context>
     <name>SystemProtectionSetting</name>
@@ -1108,5 +1141,27 @@ Jeni i sigurt se doni të vazhdohet?</translation>
         <source>Services</source>
         <translation>Shërbime</translation>
     </message>
+    <message>
+        <source>Users</source>
+        <translation>Përdorues</translation>
+    </message>
 </context>
-</TS>
+<context>
+    <name>User.Account.Type</name>
+    <message>
+        <source>Administrator</source>
+        <translation>Përgjegjës</translation>
+    </message>
+    <message>
+        <source>Standard User</source>
+        <translation>Përdorues Standard</translation>
+    </message>
+</context>
+<context>
+    <name>User.Account.Operation</name>
+    <message>
+        <source>Edit account information</source>
+        <translation>Përpunoni hollësi llogarie</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
