@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>App.About</name>
     <message>
@@ -965,10 +963,6 @@ Are you sure you want to continue?</source>
         <source>Show warnings when the usage exceeds the thresholds</source>
         <translation>当数值高于以下阈值时自动报警</translation>
     </message>
-    <message>
-        <source>Notifications</source>
-        <translation>消息通知</translation>
-    </message>
     <message>
         <source>CPU warning threshold (%)</source>
         <translation>CPU占用 (%)</translation>
@@ -981,6 +975,10 @@ Are you sure you want to continue?</source>
         <source>Warning interval (min)</source>
         <translation>预警间隔 (分钟)</translation>
     </message>
+    <message>
+        <source>Notifications</source>
+        <translation>消息通知</translation>
+    </message>
 </context>
 <context>
     <name>Service.Action.Set.Startup.Mode</name>
@@ -999,6 +997,16 @@ Are you sure you want to continue?</source>
         <source>Service instance name</source>
         <translation>服务实例名</translation>
     </message>
+    <message>
+        <source>OK</source>
+        <comment>button</comment>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>OK</source>
         <translation>确 定</translation>
@@ -1050,16 +1058,16 @@ Are you sure you want to continue?</source>
         <translation>内存加载</translation>
     </message>
     <message>
-        <source>Start State</source>
-        <translation>启动状态</translation>
+        <source>Active</source>
+        <translation type="vanished">活动</translation>
     </message>
     <message>
         <source>Sub</source>
         <translation>运行状态</translation>
     </message>
     <message>
-        <source>Start Tactic</source>
-        <translation>启用策略</translation>
+        <source>State</source>
+        <translation type="vanished">状态</translation>
     </message>
     <message>
         <source>Description</source>
@@ -1073,6 +1081,14 @@ Are you sure you want to continue?</source>
         <source>Startup Type</source>
         <translation>启动方式</translation>
     </message>
+    <message>
+        <source>Start State</source>
+        <translation>启动状态</translation>
+    </message>
+    <message>
+        <source>Start Tactic</source>
+        <translation>启用策略</translation>
+    </message>
 </context>
 <context>
     <name>SystemProtectionSetting</name>
@@ -1125,7 +1141,7 @@ Are you sure you want to continue?</source>
         <source>Services</source>
         <translation>系统服务</translation>
     </message>
-   <message>
+    <message>
         <source>Users</source>
         <translation>用户</translation>
     </message>
@@ -1148,4 +1164,4 @@ Are you sure you want to continue?</source>
         <translation>修改帐户信息</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
